@@ -23,7 +23,7 @@ import calculate.lib.utils.device as device
 from calculate.lib.utils.device import humanreadableSize
 from calculate.lib.utils import partition
 from calculate.lib.utils.files import (readLinesFile)
-from calculate.lib.utils.mount import isMount
+from calculate.lib.utils.mount import isMount, try_umount
 from calculate.install.fs_manager import FileSystemManager
 from calculate.lib.utils.tools import Sizes, traverse
 from itertools import *
@@ -295,6 +295,24 @@ class VariableClAutopartitionDevice(AutopartitionHelper, Variable):
                 if typecheck.search(fulltype):
                     raise VariableError(_("RAID %s is wrong") % dev)
 
+    def is_force_param(self):
+        return "--force" in self.Get("cl_console_args")
+
+    def get_mounted_devices(self):
+        mountedData = [(x,y) for x,y in self.ZipVars(
+            "os_disk_parent", "os_disk_dev") if isMount(y)]
+        mountedDevices = {}
+        for devices, disk  in mountedData:
+            if not isMount(disk):
+                continue
+            if self.is_force_param() and try_umount(disk):
+                continue
+            for _device in traverse(devices.split(',')):
+                if _device not in mountedDevices:
+                    mountedDevices[_device] = set()
+                mountedDevices[_device].add(disk)
+        return mountedDevices
+
     def check(self, valuelist):
         if self.Get('cl_autopartition_set') == "on":
             if not valuelist:
@@ -303,14 +321,8 @@ class VariableClAutopartitionDevice(AutopartitionHelper, Variable):
 
             useDisks = set(traverse(x.split(',') for x in self.Select(
                     'os_disk_parent', where='os_disk_mount', ne='')))
-            mountedData = [(x,y) for x,y in self.ZipVars(
-                "os_disk_parent", "os_disk_dev") if isMount(y)]
-            mountedDevices = {}
-            for devices, disk  in mountedData:
-                for _device in traverse(devices.split(',')):
-                    if _device not in mountedDevices:
-                        mountedDevices[_device] = set()
-                    mountedDevices[_device].add(disk)
+
+            mountedDevices = self.get_mounted_devices()
 
             for value in chain(valuelist):
                 for disk in set(chain(self.select(
